@@ -1,18 +1,22 @@
 """A library of helper functions for the CherryPy test suite."""
 
 import datetime
+import io
 import logging
-log = logging.getLogger(__name__)
 import os
-thisdir = os.path.abspath(os.path.dirname(__file__))
-serverpem = os.path.join(os.getcwd(), thisdir, 'test.pem')
-import unittest
-
 import re
+import subprocess
 import sys
 import time
+import unittest
 import warnings
-import io
+
+try:
+    from unittest import mock
+except ImportError:
+    import mock
+
+import nose
 import six
 
 import cherrypy
@@ -22,15 +26,10 @@ from cherrypy.lib import gctools
 from cherrypy.lib.reprconf import unrepr
 from cherrypy.test import webtest
 
-# Use subprocess module from Python 2.7 on Python 2.3-2.6
-if sys.version_info < (2, 7):
-    import cherrypy._cpcompat_subprocess as subprocess
-else:
-    import subprocess
-
-import nose
-
 _testconfig = None
+log = logging.getLogger(__name__)
+thisdir = os.path.abspath(os.path.dirname(__file__))
+serverpem = os.path.join(os.getcwd(), thisdir, 'test.pem')
 
 
 def get_tst_config(overconf={}):
@@ -38,7 +37,7 @@ def get_tst_config(overconf={}):
     if _testconfig is None:
         conf = {
             'scheme': 'http',
-            'protocol': "HTTP/1.1",
+            'protocol': 'HTTP/1.1',
             'port': 54583,
             'host': '127.0.0.1',
             'validate': False,
@@ -99,11 +98,10 @@ class LocalSupervisor(Supervisor):
         # place that i've found so far that I KNOW is early enough to set this.
         cherrypy.config.update({'log.screen': False})
         engine = cherrypy.engine
-        if hasattr(engine, "signal_handler"):
+        if hasattr(engine, 'signal_handler'):
             engine.signal_handler.subscribe()
-        if hasattr(engine, "console_control_handler"):
+        if hasattr(engine, 'console_control_handler'):
             engine.console_control_handler.subscribe()
-        #engine.subscribe('log', log_to_stderr)
 
     def start(self, modulename=None):
         """Load and start the HTTP server."""
@@ -136,24 +134,24 @@ class NativeServerSupervisor(LocalSupervisor):
 
     """Server supervisor for the builtin HTTP server."""
 
-    httpserver_class = "cherrypy._cpnative_server.CPHTTPServer"
+    httpserver_class = 'cherrypy._cpnative_server.CPHTTPServer'
     using_apache = False
     using_wsgi = False
 
     def __str__(self):
-        return "Builtin HTTP Server on %s:%s" % (self.host, self.port)
+        return 'Builtin HTTP Server on %s:%s' % (self.host, self.port)
 
 
 class LocalWSGISupervisor(LocalSupervisor):
 
     """Server supervisor for the builtin WSGI server."""
 
-    httpserver_class = "cherrypy._cpwsgi_server.CPWSGIServer"
+    httpserver_class = 'cherrypy._cpwsgi_server.CPWSGIServer'
     using_apache = False
     using_wsgi = True
 
     def __str__(self):
-        return "Builtin WSGI Server on %s:%s" % (self.host, self.port)
+        return 'Builtin WSGI Server on %s:%s' % (self.host, self.port)
 
     def sync_apps(self):
         """Hook a new WSGI app into the origin server."""
@@ -169,7 +167,7 @@ class LocalWSGISupervisor(LocalSupervisor):
                 from wsgiref import validate
             except ImportError:
                 warnings.warn(
-                    "Error importing wsgiref. The validator will not run.")
+                    'Error importing wsgiref. The validator will not run.')
             else:
                 # wraps the app in the validator
                 app = validate.validator(app)
@@ -214,8 +212,8 @@ def get_wsgi_u_supervisor(**options):
 
 class CPWebCase(webtest.WebCase):
 
-    script_name = ""
-    scheme = "http"
+    script_name = ''
+    scheme = 'http'
 
     available_servers = {'wsgi': LocalWSGISupervisor,
                          'wsgi_u': get_wsgi_u_supervisor,
@@ -226,19 +224,19 @@ class CPWebCase(webtest.WebCase):
                          'modfcgid': get_modfcgid_supervisor,
                          'modfastcgi': get_modfastcgi_supervisor,
                          }
-    default_server = "wsgi"
+    default_server = 'wsgi'
 
     @classmethod
     def _setup_server(cls, supervisor, conf):
         v = sys.version.split()[0]
-        log.info("Python version used to run this test script: %s" % v)
-        log.info("CherryPy version: %s" % cherrypy.__version__)
-        if supervisor.scheme == "https":
-            ssl = " (ssl)"
+        log.info('Python version used to run this test script: %s' % v)
+        log.info('CherryPy version: %s' % cherrypy.__version__)
+        if supervisor.scheme == 'https':
+            ssl = ' (ssl)'
         else:
-            ssl = ""
-        log.info("HTTP server version: %s%s" % (supervisor.protocol, ssl))
-        log.info("PID: %s" % os.getpid())
+            ssl = ''
+        log.info('HTTP server version: %s%s' % (supervisor.protocol, ssl))
+        log.info('PID: %s' % os.getpid())
 
         cherrypy.server.using_apache = supervisor.using_apache
         cherrypy.server.using_wsgi = supervisor.using_wsgi
@@ -255,10 +253,10 @@ class CPWebCase(webtest.WebCase):
         baseconf.update({'server.socket_host': supervisor.host,
                          'server.socket_port': supervisor.port,
                          'server.protocol_version': supervisor.protocol,
-                         'environment': "test_suite",
+                         'environment': 'test_suite',
                          })
-        if supervisor.scheme == "https":
-            #baseconf['server.ssl_module'] = 'builtin'
+        if supervisor.scheme == 'https':
+            # baseconf['server.ssl_module'] = 'builtin'
             baseconf['server.ssl_certificate'] = serverpem
             baseconf['server.ssl_private_key'] = serverpem
 
@@ -268,7 +266,7 @@ class CPWebCase(webtest.WebCase):
         # exactly like each test module does, because a relative import
         # would stick a second instance of webtest in sys.modules,
         # and we wouldn't be able to globally override the port anymore.
-        if supervisor.scheme == "https":
+        if supervisor.scheme == 'https':
             webtest.WebCase.HTTP_CONN = HTTPSConnection
         return baseconf
 
@@ -315,29 +313,29 @@ class CPWebCase(webtest.WebCase):
         if not self.do_gc_test:
             return
 
-        self.getPage("/gc/stats")
+        self.getPage('/gc/stats')
         try:
-            self.assertBody("Statistics:")
+            self.assertBody('Statistics:')
         except Exception:
-            "Failures occur intermittently. See #1420"
+            'Failures occur intermittently. See #1420'
 
     def prefix(self):
-        return self.script_name.rstrip("/")
+        return self.script_name.rstrip('/')
 
     def base(self):
-        if ((self.scheme == "http" and self.PORT == 80) or
-                (self.scheme == "https" and self.PORT == 443)):
-            port = ""
+        if ((self.scheme == 'http' and self.PORT == 80) or
+                (self.scheme == 'https' and self.PORT == 443)):
+            port = ''
         else:
-            port = ":%s" % self.PORT
+            port = ':%s' % self.PORT
 
-        return "%s://%s%s%s" % (self.scheme, self.HOST, port,
-                                self.script_name.rstrip("/"))
+        return '%s://%s%s%s' % (self.scheme, self.HOST, port,
+                                self.script_name.rstrip('/'))
 
     def exit(self):
         sys.exit()
 
-    def getPage(self, url, headers=None, method="GET", body=None,
+    def getPage(self, url, headers=None, method='GET', body=None,
                 protocol=None, raise_subcls=None):
         """Open the url. Return status, headers, body.
 
@@ -454,7 +452,7 @@ log.access_file: r'%(access_log)s'
         self.host = socket_host or cherrypy.server.socket_host
         self.port = socket_port or cherrypy.server.socket_port
 
-    def write_conf(self, extra=""):
+    def write_conf(self, extra=''):
         if self.ssl:
             serverpem = os.path.join(thisdir, 'test.pem')
             ssl = """
@@ -462,7 +460,7 @@ server.ssl_certificate: r'%s'
 server.ssl_private_key: r'%s'
 """ % (serverpem, serverpem)
         else:
-            ssl = ""
+            ssl = ''
 
         conf = self.config_template % {
             'host': self.host,
