@@ -3,8 +3,13 @@ import threading
 import time
 import socket
 
+import pytest
+
 import cherrypy
-from cherrypy._cpcompat import copykeys, HTTPConnection, HTTPSConnection
+from cherrypy._cpcompat import (
+    copykeys, json_decode,
+    HTTPConnection, HTTPSConnection
+)
 from cherrypy.lib import sessions
 from cherrypy.lib import reprconf
 from cherrypy.lib.httputil import response_codes
@@ -138,6 +143,7 @@ class SessionTest(helper.CPWebCase):
             if fname.startswith(sessions.FileSession.SESSION_PREFIX):
                 os.unlink(os.path.join(localDir, fname))
 
+    @pytest.mark.xfail(reason='#1534')
     def test_0_Session(self):
         self.getPage('/set_session_cls/cherrypy.lib.sessions.RamSession')
         self.getPage('/clear')
@@ -162,7 +168,8 @@ class SessionTest(helper.CPWebCase):
         self.getPage('/testStr', self.cookies)
         self.assertBody('3')
         self.getPage('/data', self.cookies)
-        self.assertBody("{'aha': 'foo', 'counter': 3}")
+        self.assertDictEqual(json_decode(self.body),
+                             {'counter': 3, 'aha': 'foo'})
         self.getPage('/length', self.cookies)
         self.assertBody('2')
         self.getPage('/delkey?key=counter', self.cookies)
@@ -216,6 +223,7 @@ class SessionTest(helper.CPWebCase):
         self.getPage('/set_session_cls/cherrypy.lib.sessions.RamSession')
         self._test_Concurrency()
 
+    @pytest.mark.xfail(reason='#1306')
     def test_2_File_Concurrency(self):
         self.getPage('/set_session_cls/cherrypy.lib.sessions.FileSession')
         self._test_Concurrency()
@@ -370,9 +378,13 @@ class SessionTest(helper.CPWebCase):
 
         t = threading.Thread(target=lock)
         t.start()
+        start = time.time()
+        while not sessions.RamSession.locks and time.time() - start < 5:
+            time.sleep(0.01)
+        assert len(sessions.RamSession.locks) == 1, 'Lock not acquired'
         s2 = sessions.RamSession()
         s2.clean_up()
-        self.assertEqual(len(sessions.RamSession.locks), 1, 'Clean up should not remove active lock')
+        assert len(sessions.RamSession.locks) == 1, 'Clean up should not remove active lock'
         t.join()
 
 
